# Pybsky

<div align='center'>
    <img src=assets/cover.png height="150" width="500" alt="pybsky-logo" >

</div>

## TODO List:

- [x] Create Client
- [x] Add Login logic
- [ ] Get Profile logic
- [ ] Get Follwer/Following logic
- [ ] Follow/Unfollow
- [ ] Get Likers
- [ ] Get Commenters
- [ ] Get Feed/Timeline
- [ ] Post skeets

## License

[![License](http://img.shields.io/:license-mit-blue.svg?style=flat-square)](http://badges.mit-license.org)

- This project is licensed under the terms of the **[MIT license](LICENSE)**
